##  Selecting Fact Sheet Shape Templates
You can use all shape templates in free draw and data flow diagrams. When your administrator sets a default template, it appears as the default choice in the Fact Sheet Shape Template dropdown on the right panel of the diagram editor.
You can select any template from the dropdown for the current diagram. When you add fact sheets in the diagram editor, the shapes from the selected template are used to represent your fact sheets.
To select a template, do the following:
  1. Open a diagram in edit mode.
  2. In the Data tab of the right panel, select the template from the Fact Sheet Shape Template dropdown.


![Diagram editor with Fact Sheet Shape Template dropdown expanded in the right panel.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio880ec9640d66419e9e0d0810be174a43_LowRes.png)
Selecting a Template in the Diagram Editor
